==> haskell-yesod-static-1.5.1.1-33-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.1.1
id: yesod-static-1.5.1.1-ejzsdBHoXj88erHUnrb63
key: yesod-static-1.5.1.1-ejzsdBHoXj88erHUnrb63
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: b3c9e177c9218de8922029fcc0c2f145
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-static-1.5.1.1
hs-libraries: HSyesod-static-1.5.1.1-ejzsdBHoXj88erHUnrb63
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-1ZuWtV54hevB7dRz7GoUMb containers-0.5.7.1
    cryptohash-0.11.9-58MQCkevJarJihmcTE8nlX
    cryptohash-conduit-0.1.1-8d1zh9RgAUs5MVlZUnX4Bt
    css-text-0.1.2.2-ID6dFT9pfdSA5gvNaIq3qA
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ filepath-1.4.1.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hjsmin-0.2.0.2-BEH1Ch8p8LmFbydn4PrYHw
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp process-1.4.2.0
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    wai-app-static-3.1.6.1-5Hcbtxvb3rG6h0iU5SqGy4
    yesod-core-1.4.31-Dj1AbxAUlyH6Ifzak0eX8
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.5.1.1-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.1.1
id: yesod-static-1.5.1.1-9s5azYxVxRx4k0fJQjmWcY
key: yesod-static-1.5.1.1-9s5azYxVxRx4k0fJQjmWcY
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Static Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Generators
    Yesod.EmbeddedStatic.Types Yesod.EmbeddedStatic.Css.AbsoluteUrl
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: 5a156132867d8154a4781248b946be4e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.1.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-static-1.5.1.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-static-1.5.1.1
hs-libraries: HSyesod-static-1.5.1.1-9s5azYxVxRx4k0fJQjmWcY
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    conduit-1.2.9-FSMMZIzF7gQEWXyv5oTHal
    conduit-extra-1.1.15-78qe38B2RDSInfoQ5hOgKH containers-0.5.7.1
    cryptohash-0.11.9-58MQCkevJarJihmcTE8nlX
    cryptohash-conduit-0.1.1-5LS2NQ7varfD5sbhWDbBnI
    css-text-0.1.2.2-ID6dFT9pfdSA5gvNaIq3qA
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ filepath-1.4.1.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hjsmin-0.2.0.2-BEH1Ch8p8LmFbydn4PrYHw
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    mime-types-0.1.0.7-1TVT7pakOnO6kciNbLYizr
    old-time-1.1.0.3-IcvdkJUsE9M8t3io8peAEp process-1.4.2.0
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC template-haskell-2.11.0.0
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    wai-app-static-3.1.6.1-Idrua7CdTRHK4z2DZQUQJ6
    yesod-core-1.4.31-13JncrFhNmF1As6AFyCxz9
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
